==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-mount/translations/mount_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства и носители</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Настройки на сменяеми устройства</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation>При свързване на устройство:</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation>При натискане на бутона за извеждане на устройство:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>Изскачащо меню</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="44"/>
        <source>Show info</source>
        <translation>Показване на информация</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="45"/>
        <location filename="../configuration.cpp" line="50"/>
        <source>Do nothing</source>
        <translation>Без извършване на действие</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="51"/>
        <source>Eject All Optical Drives</source>
        <translation>Извеждане на всички оптични устройства</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Устройство &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; е свързано.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Устройство &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; е премахнато.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства и носители</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства и носители</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation>Всички оптични устройства са извадени</translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>Управление на сменяеми устройства: Комбинация &apos;%1&apos; не може да се регистрира</translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation>Изваждане на сменяем носител</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="153"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>Монтиране на &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; неуспешно: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="174"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Демонтиране на &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; неуспешно: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Не са налични устройства</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-mount/translations/mount_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства и носители</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Настройки на сменяеми устройства</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation>При свързване на устройство:</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Стартиране на следното действие при натискане на бутона изваждане (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation>При натискане на бутона за извеждане на устройство:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>Изскачащо меню</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="45"/>
        <source>Show info</source>
        <translation>Показване на информация</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="46"/>
        <location filename="../configuration.cpp" line="51"/>
        <source>Do nothing</source>
        <translation>Без извършване на действие</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="52"/>
        <source>Eject All Optical Drives</source>
        <translation>Извеждане на всички оптични устройства</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Устройство &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; е свързано.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Устройство &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; е премахнато.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства и носители</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства и носители</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation>Всички оптични устройства са извадени</translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>Управление на сменяеми устройства: Комбинация &apos;%1&apos; не може да се регистрира</translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation>Изваждане на сменяем носител</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="153"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>Монтиране на &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; неуспешно: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Removable media/devices manager</source>
        <translation>Управление на сменяеми устройства</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="174"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Демонтиране на &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; неуспешно: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Не са налични устройства</translation>
    </message>
</context>
</TS>
